#!/bin/sh

git clone https://github.com/DeaDBeeF-Player/apbuild external/apbuild
cd external/apbuild && git -c advice.detachedHead=false checkout 2ca657b
cd ../..

git clone https://github.com/DeaDBeeF-Player/ddb_dsp_libretro external/ddb_dsp_libretro
cd external/ddb_dsp_libretro && git -c advice.detachedHead=false checkout 5dd81e9
cd ../..

git clone https://github.com/DeaDBeeF-Player/ddb_output_pw external/ddb_output_pw
cd external/ddb_output_pw && git -c advice.detachedHead=false checkout a9f7d1b
cd ../..

git clone https://github.com/DeaDBeeF-Player/googletest external/googletest
cd external/googletest && git -c advice.detachedHead=false checkout 3fa7f98
cd ../..

git clone https://github.com/DeaDBeeF-Player/mp4p external/mp4p
cd external/mp4p && git -c advice.detachedHead=false checkout 156195c
cd ../..

rm -rf external/apbuild/.*
rm -rf external/ddb_dsp_libretro/.*
rm -rf external/ddb_output_pw/.*
rm -rf external/googletest/.*
rm -rf external/mp4p/.*
